..
    Copyright (C) 2019 Esteban J. Garcia Gabancho.
    Copyright (C) 2021 Graz University of Technology.

    Invenio-SAML is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Authors
=======

Invenio module that provides SAML integration.

- Esteban J. Garcia Gabancho <egabancho@gmail.com>
- Mojib Wali <mb_wali@hotmail.com>
